# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot8
from purity_fb_1dot8.rest import ApiException
from purity_fb_1dot8.apis.certificate_groups_api import CertificateGroupsApi


class TestCertificateGroupsApi(unittest.TestCase):
    """ CertificateGroupsApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot8.apis.certificate_groups_api.CertificateGroupsApi()

    def tearDown(self):
        pass

    def test_add_certificate_group_certificates(self):
        """
        Test case for add_certificate_group_certificates

        
        """
        pass

    def test_create_certificate_groups(self):
        """
        Test case for create_certificate_groups

        
        """
        pass

    def test_delete_certificate_groups(self):
        """
        Test case for delete_certificate_groups

        
        """
        pass

    def test_list_certificate_group_certificates(self):
        """
        Test case for list_certificate_group_certificates

        
        """
        pass

    def test_list_certificate_group_uses(self):
        """
        Test case for list_certificate_group_uses

        
        """
        pass

    def test_list_certificate_groups(self):
        """
        Test case for list_certificate_groups

        
        """
        pass

    def test_remove_certificate_group_certificates(self):
        """
        Test case for remove_certificate_group_certificates

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
