# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot10
from purity_fb_1dot10.rest import ApiException
from purity_fb_1dot10.models.syslog_server_post_or_patch import SyslogServerPostOrPatch


class TestSyslogServerPostOrPatch(unittest.TestCase):
    """ SyslogServerPostOrPatch unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSyslogServerPostOrPatch(self):
        """
        Test SyslogServerPostOrPatch
        """
        # FIXME: construct object with mandatory attributes with example values
        #model = purity_fb_1dot10.models.syslog_server_post_or_patch.SyslogServerPostOrPatch()
        pass


if __name__ == '__main__':
    unittest.main()
