# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot9
from purity_fb_1dot9.rest import ApiException
from purity_fb_1dot9.apis.keytabs_api import KeytabsApi


class TestKeytabsApi(unittest.TestCase):
    """ KeytabsApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot9.apis.keytabs_api.KeytabsApi()

    def tearDown(self):
        pass

    def test_delete_keytabs(self):
        """
        Test case for delete_keytabs

        
        """
        pass

    def test_download_keytab_file(self):
        """
        Test case for download_keytab_file

        
        """
        pass

    def test_list_keytabs(self):
        """
        Test case for list_keytabs

        
        """
        pass

    def test_upload_keytab_file(self):
        """
        Test case for upload_keytab_file

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
