# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot9
from purity_fb_1dot9.rest import ApiException
from purity_fb_1dot9.apis.bucket_replica_links_api import BucketReplicaLinksApi


class TestBucketReplicaLinksApi(unittest.TestCase):
    """ BucketReplicaLinksApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot9.apis.bucket_replica_links_api.BucketReplicaLinksApi()

    def tearDown(self):
        pass

    def test_create_bucket_replica_links(self):
        """
        Test case for create_bucket_replica_links

        
        """
        pass

    def test_delete_bucket_replica_links(self):
        """
        Test case for delete_bucket_replica_links

        
        """
        pass

    def test_list_bucket_replica_links(self):
        """
        Test case for list_bucket_replica_links

        
        """
        pass

    def test_update_bucket_replica_links(self):
        """
        Test case for update_bucket_replica_links

        
        """
        pass


if __name__ == '__main__':
    unittest.main()
